@@ -146,10 +146,13 @@ class SingletonAdmin(admin.ModelAdmin):
         try:
             singleton = self.model.objects.get()
         except (self.model.DoesNotExist, self.model.MultipleObjectsReturned):
-            return super(SingletonAdmin, self).add_view(*args, **kwargs)
-        else:
-            change_url = admin_url(self.model, "change", singleton.id)
-            return redirect(change_url)
+            kwargs.setdefault("extra_context", {})
+            kwargs["extra_context"]["singleton"] = True
+            response = super(SingletonAdmin, self).add_view(*args, **kwargs)
+            if args[0].POST.get("_save"):
+                response = redirect("admin:index")
+            return response
+        return redirect(admin_url(self.model, "change", singleton.id))
 
     def changelist_view(self, *args, **kwargs):
         """
@@ -161,28 +164,18 @@ class SingletonAdmin(admin.ModelAdmin):
         except self.model.MultipleObjectsReturned:
             return super(SingletonAdmin, self).changelist_view(*args, **kwargs)
         except self.model.DoesNotExist:
-            add_url = admin_url(self.model, "add")
-            return redirect(add_url)
-        else:
-            change_url = admin_url(self.model, "change", singleton.id)
-            return redirect(change_url)
+            return redirect(admin_url(self.model, "add"))
+        return redirect(admin_url(self.model, "change", singleton.id))
 
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, *args, **kwargs):
         """
         If only the singleton instance exists, pass ``True`` for
         ``singleton`` into the template which will use CSS to hide
         the "save and add another" button.
         """
-        if extra_context is None:
-            extra_context = {}
-        try:
-            self.model.objects.get()
-        except (self.model.DoesNotExist, self.model.MultipleObjectsReturned):
-            pass
-        else:
-            extra_context["singleton"] = True
-        response = super(SingletonAdmin, self).change_view(request, object_id,
-                                                           extra_context)
-        if request.POST.get("_save"):
+        kwargs.setdefault("extra_context", {})
+        kwargs["extra_context"]["singleton"] = self.model.objects.count() == 1
+        response = super(SingletonAdmin, self).change_view(*args, **kwargs)
+        if args[0].POST.get("_save"):
             response = redirect("admin:index")
         return response
