@@ -1,4 +1,6 @@
 
+from socket import gethostname
+
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.contrib.auth import models as auth_app
@@ -30,7 +32,7 @@ def create_user(app, created_models, verbosity, interactive, **kwargs):
 
 def create_pages(app, created_models, verbosity, interactive, **kwargs):
     required = set([Page, Form, Gallery])
-    if settings.DEBUG and required.issubset(set(created_models)):
+    if required.issubset(set(created_models)):
         if interactive:
             confirm = raw_input("\nWould you like to install some initial "
                                 "content?\nEg: About page, Blog, Contact "
@@ -55,13 +57,21 @@ def create_pages(app, created_models, verbosity, interactive, **kwargs):
 
 
 def create_site(app, created_models, verbosity, interactive, **kwargs):
-    if settings.DEBUG and Site in created_models:
-        domain = "127.0.0.1:8000"
+    if Site in created_models:
+        domain = "127.0.0.1:8000" if settings.DEBUG else gethostname()
+        if interactive:
+            entered = raw_input("\nA site record is required. Please enter "
+                                "the domain and optional port in the format "
+                                "'domain:port'. For example 'localhost:8000' "
+                                "or 'www.example.com'. Hit enter to use the "
+                                "default (%s): " % domain)
+            if entered:
+                domain = entered.strip("': ")
         if verbosity >= 1:
             print
             print "Creating default Site %s ... " % domain
             print
-        Site.objects.create(name="Local development", domain=domain)
+        Site.objects.create(name="Default", domain=domain)
 
 if not settings.TESTING:
     post_syncdb.connect(create_user, sender=auth_app)
