@@ -1,3 +1,4 @@
+
 from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.http import HttpResponse
 from django.shortcuts import redirect
@@ -7,6 +8,7 @@ from mezzanine.conf import settings
 from mezzanine.pages import page_processors
 from mezzanine.pages.models import Page
 from mezzanine.pages.views import page as page_view
+from mezzanine.utils.urls import path_to_slug
 
 
 class PageMiddleware(object):
@@ -32,27 +34,12 @@ class PageMiddleware(object):
 
     def process_view(self, request, view_func, view_args, view_kwargs):
 
-        # Remove the page slug which is set when the blog is at
-        # the root of the site (BLOG_SLUG is empty).
-        from mezzanine.urls import PAGES_SLUG
-        slug = request.path_info.replace(PAGES_SLUG, "", 1)
-
-        if slug == "/":
-            slugs = [slug]
+        slug = path_to_slug(request.path_info)
+        pages = Page.objects.with_ascendants_for_slug(slug,
+                        for_user=request.user, include_login_required=True)
+        if pages:
+            page = pages[0]
         else:
-            slug = slug.strip("/")
-            # Create a list containing this slug, plus each of the
-            # ascendant slugs: ['about', 'about/team', 'about/team/mike']
-            parts = slug.split("/")
-            slugs = ["/".join(parts[:i]) for i in range(1, len(parts) + 1)]
-
-        pages_for_user = Page.objects.published(request.user)
-        try:
-            # Find the deepest page that matches one of our slugs.
-            # Sorting by "-slug" ensures that the page with the
-            # longest slug is selected if more than one page matches.
-            page = pages_for_user.filter(slug__in=slugs).order_by("-slug")[0]
-        except IndexError:
             # If we can't find a page matching this slug or any
             # of its sub-slugs, skip all further processing.
             return view_func(request, *view_args, **view_kwargs)
@@ -87,7 +74,7 @@ class PageMiddleware(object):
         # Run page processors.
         model_processors = page_processors.processors[page.content_model]
         slug_processors = page_processors.processors["slug:%s" % page.slug]
-        for (processor, exact_page) in model_processors + slug_processors:
+        for (processor, exact_page) in slug_processors + model_processors:
             if exact_page and not page.is_current:
                 continue
             processor_response = processor(request, page)
